@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2006 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2010 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -61,6 +61,10 @@ import com.gargoylesoftware.htmlunit.html.HtmlAnchor;
 import com.gargoylesoftware.htmlunit.html.HtmlPage;
 import com.openexchange.groupware.container.Contact;
 import com.openexchange.subscribe.SubscriptionException;
+import com.openexchange.subscribe.crawler.internal.AbstractStep;
+import com.openexchange.subscribe.crawler.internal.ContactSanitizer;
+import com.openexchange.subscribe.crawler.internal.Mappings;
+import com.openexchange.subscribe.crawler.internal.PagePartSequence;
 import com.openexchange.tools.versit.VersitException;
 import com.openexchange.tools.versit.converter.ConverterException;
 
@@ -102,9 +106,13 @@ public class ContactObjectsByHTMLAnchorsAndPagePartSequenceStep extends Abstract
     public void execute(final WebClient webClient) throws SubscriptionException {
         final List<Contact> contactObjects = new ArrayList<Contact>();
         // final OXContainerConverter oxContainerConverter = new OXContainerConverter((TimeZone) null, (String) null);
+        HtmlPage debugPage = null;
         for (final HtmlAnchor anchor : input) {
             try {
                 HtmlPage page = anchor.click();
+                if (isDebuggingEnabled()){
+                    debugPage = page;
+                }
                 // in case the reached page is not yet the one with (all) the contact info and there is one more link to click
                 if (!linkToTargetPage.equals("")){
                    final PageByLinkRegexStep step = new PageByLinkRegexStep("", linkToTargetPage);
@@ -116,6 +124,7 @@ public class ContactObjectsByHTMLAnchorsAndPagePartSequenceStep extends Abstract
                 if (null != titleText && !titleText.matches(titleExceptionsRegex)){
                     final String pageString = StringEscapeUtils.unescapeHtml(page.getWebResponse().getContentAsString());                
                     pageParts.setPage(pageString);
+                    LOG.debug("Page evaluated is : "+pageString);
                     final HashMap<String, String> map = pageParts.retrieveInformation();
     
                     final Contact contact = Mappings.translateMapToContact(map);
@@ -138,7 +147,9 @@ public class ContactObjectsByHTMLAnchorsAndPagePartSequenceStep extends Abstract
             }
             executedSuccessfully = true;
         }
-
+        if (input.isEmpty()) {
+            executedSuccessfully = true;
+        }
         output = contactObjects.toArray(new Contact[contactObjects.size()]);
 
     }
