@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2006 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2010 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -49,6 +49,9 @@
 
 package com.openexchange.subscribe.crawler;
 
+import com.openexchange.groupware.container.FolderObject;
+import com.openexchange.subscribe.crawler.osgi.Activator;
+
 /**
  * @author <a href="mailto:karsten.will@open-xchange.com">Karsten Will</a>
  */
@@ -57,6 +60,13 @@ public class CrawlerDescription {
     private String displayName, id, workflowString;
     
     private int priority = 0;
+    
+    private int crawlerApiVersion = 614;
+    
+    // set the default module to CONTACT to be compatible with API-Version 614
+    private int module = FolderObject.CONTACT;
+    
+    private boolean javascriptEnabled = false;
 
     public CrawlerDescription() {
 
@@ -97,5 +107,35 @@ public class CrawlerDescription {
     }
 
     
+    public int getCrawlerApiVersion() {
+        return crawlerApiVersion;
+    }
+
+    
+    public void setCrawlerApiVersion(int crawlerApiVersion) {
+        this.crawlerApiVersion = crawlerApiVersion;
+    }
+
+    
+    public int getModule() {
+        return module;
+    }
+
+    
+    public void setModule(int module) {
+        this.module = module;
+    }
+
+    
+    public boolean isJavascriptEnabled() {
+        return javascriptEnabled;
+    }
+
+    
+    public void setJavascriptEnabled(boolean javascriptEnabled) {
+        this.javascriptEnabled = javascriptEnabled;
+    }
+
+    
     
 }
