@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2006 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2010 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -51,10 +51,9 @@ package com.openexchange.subscribe.crawler;
 
 import java.util.ArrayList;
 import org.ho.yaml.Yaml;
-
-//import com.openexchange.server.services.ServerServiceRegistry;
-//import com.openexchange.timer.TimerService;
-//import com.openexchange.timer.internal.TimerImpl;
+import com.openexchange.subscribe.crawler.internal.PagePart;
+import com.openexchange.subscribe.crawler.internal.PagePartSequence;
+import com.openexchange.subscribe.crawler.internal.Step;
 
 /**
  * @author <a href="mailto:karsten.will@open-xchange.com">Karsten Will</a>
@@ -70,32 +69,22 @@ public class GenericSubscribeServiceForLinkedInTest extends GenericSubscribeServ
         CrawlerDescription crawler = new CrawlerDescription();
         crawler.setDisplayName("LinkedIn");
         crawler.setId("com.openexchange.subscribe.linkedin");
-
-        // initiate the TimerService for MultiThreading
-        // final TimerImpl timer = new TimerImpl();
-        // timer.start();
-        // ServerServiceRegistry.getInstance().addService(TimerService.class, timer);
+        crawler.setCrawlerApiVersion(616);
+        crawler.setPriority(4);
 
         ArrayList<Step> listOfSteps = new ArrayList<Step>();
 
-        listOfSteps.add(new LoginPageStep(
-            "Login to www.linkedin.com",
-            "https://www.linkedin.com/secure/login",
-            "",
-            "",
-            "login",
-            "session_key",
-            "session_password",
-            "/connections?trk=hb_side_cnts",
-            "https://www.linkedin.com"));
-        listOfSteps.add(new PageByUrlStep("Get to the contacts list", "http://www.linkedin.com/connections?trk=hb_side_cnts"));
+        listOfSteps.add(new LoginWithHttpClientStep("Call LinkedIn with all parameters that are normally set by the login-form",
+            "https://www.linkedin.com/secure/login?session_key=USERNAME&session_password=PASSWORD&session_login=&session_rikey=&csrfToken=ajax:6545267463289092740",
+            ".*manual_redirect_link.*"));
+        
         listOfSteps.add(new PageByUrlStep(
             "Get to the no-javascript contacts list",
             "http://www.linkedin.com/connectionsnojs?trk=cnx_nojslink"));
         listOfSteps.add(new AnchorsByLinkRegexStep(
             "Get all pages that link to a connections profile",
             "(/connectionsnojs\\?split_page=).*",
-            "(/profile\\?viewProfile=).*(goback).*"));
+            "(/profile\\?viewProfile=).*(goback).*", true));
         ArrayList<PagePart> pageParts = new ArrayList<PagePart>();
         pageParts.add(new PagePart(
             "(<img src=\")([a-zA-Z://\\._0-9]*)(\" class=\"photo\" width=\"80\" height=\"80\" alt=\"[a-zA-Z\u00e4\u00f6\u00fc\\s]*\">)",
@@ -131,8 +120,8 @@ public class GenericSubscribeServiceForLinkedInTest extends GenericSubscribeServ
         Workflow workflow = new Workflow(listOfSteps);
         crawler.setWorkflowString(Yaml.dump(workflow));
 
-        //findOutIfThereAreContactsForThisConfiguration(username, password, crawler, true);
+        findOutIfThereAreContactsForThisConfiguration(username, password, crawler, true);
         // uncomment this if the crawler description was updated to get the new config-files
-        //dumpThis(crawler, crawler.getDisplayName());
+        // dumpThis(crawler, crawler.getDisplayName());
     }
 }
